# prettyjson [![Build Status](https://secure.travis-ci.org/rafeca/prettyjson.png)](http://travis-ci.org/rafeca/prettyjson)

Package for formatting JSON data in a coloured YAML-style, perfect for CLI output

## How to install

The easiest way is by installing it from the `npm` repository:
    
    $ npm install prettyjson

## Using it (from the CLI)

This package installs a command line interface to render JSON data in a more convenient way. You can use the CLI
in three different ways:

**Decode a JSON file:** If you want to see the contents of a JSON file, just pass it as the first argument to the CLI:
    
    $ prettyjson package.json

![Example 1](http://rafeca.com/prettyjson/images/example3.png)

**Decode the stdin:** You can also pipe the result of a command (for example an HTTP request) to the CLI to see
the JSON result in a clearer way:
    
    $ curl https://api.github.com/users/rafeca | prettyjson

![Example 2](http://rafeca.com/prettyjson/images/example4.png)

**Decode random strings:** if you call the CLI with no arguments, you'll get a prompt where you can past JSON strings
and they'll be automatically displayed in a clearer way:

![Example 3](http://rafeca.com/prettyjson/images/example5.png)

If you install the package globally (with `npm install -g prettyjson`), the CLI will be installed automatically in your PATH
thanks to npm.

## Using it (from Node.js)

It's pretty easy to use it... you just have to include it in your script and call the `render()` method:
    
    var prettyjson = require('prettyjson');
    
    var data = {
      username: 'rafeca',
      url: 'https://github.com/rafeca',
      twitter_account: 'https://twitter.com/rafeca',
      projects: ['prettyprint', 'connfu']
    };
    
    console.log(prettyjson.render(data));

And will output:
    
![Example 4](http://rafeca.com/prettyjson/images/example1.png)

You can also configure the colors of the hash keys and array dashes
(using [colors.js](https://github.com/Marak/colors.js) colors syntax):
    
    var prettyjson = require('prettyjson');

    var data = {
      username: 'rafeca',
      url: 'https://github.com/rafeca',
      twitter_account: 'https://twitter.com/rafeca',
      projects: ['prettyprint', 'connfu']
    };

    console.log(prettyjson.render(data, {
      keysColor: 'rainbow', 
      dashColor: 'magenta'
    }));

Will output something like:

![Example 5](http://rafeca.com/prettyjson/images/example2.png)

## Annotated source

You can check the [annotated source](http://rafeca.com/prettyjson/prettyjson.html) for more information about how it works

## Running Tests

To run the test suite first invoke the following command within the repo, installing the development dependencies:
    
    $ npm install --dev

then run the tests:
    
    $ npm test

